Here is the list of bug the fuzzer have found

* so many issues on production infra 
* after merging two documents, the merged document should not appears in `GET /documents`
* blocked users should be able to get logs, and use user_tags
